## Changelog 🔄
All notable changes to `isaacus-sagemaker` will be documented here. This project adheres to [Keep a Changelog](https://keepachangelog.com/en/1.1.0/) and [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.0] - 2025-XX-XX
### Added
- Initial release of `isaacus-sagemaker`, providing synchronous and asynchronous HTTP clients for interacting with Isaacus models deployed on AWS SageMaker via the SageMaker Runtime InvokeEndpoint API.

[0.1.0]: https://github.com/isaacus-dev/isaacus-sagemaker-python/releases/tag/v0.1.0